@@ -4,12 +4,11 @@ use futures_util::stream::SplitSink;
 use futures_util::SinkExt;
 use ockam_core::{async_trait, Result, Routed, TransportMessage, Worker};
 use ockam_node::Context;
+use ockam_transport_core::TransportError;
 use tokio::io::{AsyncRead, AsyncWrite};
 use tokio_tungstenite::tungstenite::protocol::Message as WebSocketMessage;
 use tokio_tungstenite::WebSocketStream;
 
-use crate::WebSocketError;
-
 /// A WebSocket sending message worker
 ///
 /// This half of the worker is created when spawning a new connection
@@ -45,7 +44,7 @@ where
         msg.onward_route.step()?;
 
         // Create a message buffer with pre-pended length
-        let msg = serde_bare::to_vec(&msg.body()).map_err(|_| WebSocketError::SendBadMessage)?;
+        let msg = serde_bare::to_vec(&msg.body()).map_err(|_| TransportError::SendBadMessage)?;
         if self
             .ws_sink
             .send(WebSocketMessage::from(msg))
